@@ -14,7 +14,6 @@
 #define __output_h__
 
 extern	FILE	*irclog_fp;
-struct ScreenStru;
 
 	BUILT_IN_COMMAND(extern_write);
 	void	put_echo		(const unsigned char *);
@@ -31,4 +30,8 @@ struct ScreenStru;
 	int	init_screen 		(void);
 	void   	file_put_it 		(FILE *fp, const char *format, ...);
 
+        int     get_window_display              (void);
+        int     set_window_display              (int);
+        int     swap_window_display             (int);
+
 #endif /* _OUTPUT_H_ */
