@@ -131,7 +131,7 @@ static 	void 	exec_close_in		(Process *);
 static 	void 	exec_close_out		(Process *);
 static 	void 	kill_process 		(Process *, int);
 static 	void 	kill_all_processes 	(int signo);
-static 	int 	is_logical_unique 	(char *logical);
+static 	int 	is_logical_unique 	(const char *logical);
 static	void 	do_exec 		(int fd);
 static	Process *	get_process_by_refnum (int refnum);
 static int 	get_process_refnum 	(const char *desc);
@@ -557,11 +557,17 @@ int 		text_to_process (const char *target, const char *text, int show)
 	if (write(proc->p_stdin, recoded_text, strlen(recoded_text)) <= 0)
 		yell("Was unable to write text %s to process %s", text, target);
 	new_free(&extra);
-	set_prompt_by_refnum(proc->window_refnum, empty_string);
+#if 0
+	set_window_prompt(proc->window_refnum, empty_string);
+#endif
 
 	if (show)
 		if ((do_hook(SEND_EXEC_LIST, "%s %d %s", logical_name, process_refnum, text)))
-			put_it("%s%s", get_prompt_by_refnum(proc->window_refnum), text);
+#if 0
+			put_it("%s%s", get_window_prompt(proc->window_refnum), text);
+#else
+			put_it("%s", text);
+#endif
 
 	pop_message_from(l);
 	return (0);
@@ -891,8 +897,7 @@ static void 	kill_all_processes (int signo)
 	int	i;
 	int	tmp;
 
-	tmp = window_display;
-	window_display = 0;
+	tmp = swap_window_display(0);
 	for (i = 0; i < process_list_size; i++)
 	{
 		if (process_list[i])
@@ -901,14 +906,14 @@ static void 	kill_all_processes (int signo)
 			kill_process(process_list[i], signo);
 		}
 	}
-	window_display = tmp;
+	swap_window_display(tmp);
 }
 
 
 
 
 /* * * * * * logical stuff * * * * * * */
-static int 	is_logical_unique (char *logical)
+static int 	is_logical_unique (const char *logical)
 {
 	Process	*proc;
 	int	i;
@@ -1338,7 +1343,7 @@ static int	start_process (Process *proc)
  *		/bin/sh -c you_commands_here
  */
 
-static void	execcmd_push_arg (char **arg_list, size_t arg_list_size, int arg_list_idx, char *flag)
+static void	execcmd_push_arg (const char **arg_list, size_t arg_list_size, int arg_list_idx, const char *flag)
 {
 	if (arg_list_idx >= 0 && (unsigned long)arg_list_idx < arg_list_size - 1)
 	{
@@ -1349,9 +1354,9 @@ static void	execcmd_push_arg (char **arg_list, size_t arg_list_size, int arg_lis
 		/* yell("Not adding [%s] argument to list - overflow", flag) */ (void) 0;
 }
 
-static char **	execcmd_tokenize_arguments (const char *args, Process **process, char **free_ptr, char **extra_args, int *numargs, int *flags_size)
+static const char **	execcmd_tokenize_arguments (const char *args, Process **process, char **free_ptr, char **extra_args, int *numargs, int *flags_size)
 {
-	char **	arg_list;
+	const char **	arg_list;
 	int	arg_list_size;
 	int	arg_list_idx;
 	char *	args_copy;
@@ -1364,7 +1369,7 @@ static char **	execcmd_tokenize_arguments (const char *args, Process **process,
 
 	/* XXX hardcoding 64 here is bogus */
 	arg_list_size = 64;
-	arg_list = (char **)new_malloc(sizeof(char *) * arg_list_size);
+	arg_list = (const char **)new_malloc(sizeof(const char *) * arg_list_size);
 	arg_list_idx = 0;
 
 	while ((args_copy && *args_copy == '-')  && (flag = next_arg(args_copy, &args_copy)))
@@ -1553,7 +1558,7 @@ BUILT_IN_COMMAND(execcmd)
 {
 	char *	free_ptr;
 	Process *process;
-	char **	flags;
+	const char **	flags;
 	int	flags_size;
 	char *	extra_args;
 	int	numargs;
@@ -1590,7 +1595,7 @@ BUILT_IN_COMMAND(execcmd)
 
 		else if (my_strnicmp(flag, "-NAME", len) == 0)
 		{
-			char *new_name = flags[++i];
+			const char *new_name = flags[++i];
 
 			if (is_logical_unique(new_name))
 			{
@@ -1606,7 +1611,7 @@ BUILT_IN_COMMAND(execcmd)
 		{
 			const char *who;
 
-			if (!(who = get_target_by_refnum(0)))
+			if (!(who = get_window_target(0)))
 				say("No query or channel in this window for -OUT");
 			else
 			{
@@ -1619,20 +1624,20 @@ BUILT_IN_COMMAND(execcmd)
 		{
 			pop_message_from(l);
 			l = set_message_from_for_process(process);
-			process->window_refnum = current_refnum();
+			process->window_refnum = get_window_refnum(0);
 			say("Output from process %d (%s) now going to window %d", 
 					process->refnum, process->commands, process->window_refnum);
 		}
 		else if (my_strnicmp(flag, "-WINTARGET", len) == 0)
 		{
 			const char *desc = flags[++i];
-			Window *w;
+			int	w;
 
-			if (!desc || !(w = get_window_by_desc(desc)))
+			if (!desc || (w = lookup_window(desc)) < 1)
 				say("Target window not found");
 			else
 			{
-				process->window_refnum = w->refnum;
+				process->window_refnum = w;
 				pop_message_from(l);
 				l = set_message_from_for_process(process);
 				say("Output from process %d (%s) now going to window %d", 
