@@ -40,19 +40,19 @@
 /*
  * irc_version is what $J returns, its the common-name for the version.
  */
-const char irc_version[] = "EPIC5-2.1.7";
-const char useful_info[] = "epic5 2 1 7";
+const char irc_version[] = "EPIC5-2.1.9";
+const char useful_info[] = "epic5 2 1 9";
 
 /*
  * internal_version is what $V returns, its the integer-id for the
  * version, and corresponds to the date of release, YYYYMMDD.
  */ 
-const char internal_version[] = "20220327";
+const char internal_version[] = "20220509";
 
 /*
  * In theory, this number is incremented for every commit.
  */
-const unsigned long	commit_id = 2011;
+const unsigned long	commit_id = 2053;
 
 /*
  * As a way to poke fun at the current rage of naming releases after
@@ -60,7 +60,7 @@ const unsigned long	commit_id = 2011;
  * reality, I have decided to start doing that with EPIC.  These names
  * are intentionally and maliciously silly.  Complaints will be ignored.
  */
-const char ridiculous_version_name[] = "Cinereous";
+const char ridiculous_version_name[] = "Decoupage";
 
 #define __need_putchar_x__
 #include "status.h"
@@ -244,7 +244,7 @@ void	irc_exit (int really_quit, const char *format, ...)
 {
 	char 	buffer[BIG_BUFFER_SIZE];
 	char *	quit_message = NULL;
-	int	old_window_display = window_display;
+	int	old_window_display;
 	int	value;
 
 	/*
@@ -282,9 +282,6 @@ void	irc_exit (int really_quit, const char *format, ...)
 
 	/* Do some clean up */
 	do_hook(EXIT_LIST, "%s", buffer);
-#ifdef HAVE_TCL
-	tclstartstop(0);
-#endif
 #ifdef HAVE_PERL
 	perlstartstop(0);  /* In case there's perl code in the exit hook. */
 #endif
@@ -309,7 +306,7 @@ void	irc_exit (int really_quit, const char *format, ...)
 	}
 	
 	/* Try to free as much memory as possible */
-	window_display = 0;
+	old_window_display = swap_window_display(0);
 /*	dumpcmd(NULL, NULL, NULL); */
 	remove_channel(NULL, 0);
 	set_lastlog_size(&value);
@@ -319,7 +316,8 @@ void	irc_exit (int really_quit, const char *format, ...)
 	remove_bindings();
 	flush_on_hooks();
 	flush_all_symbols();
-	window_display = old_window_display;
+	swap_window_display(old_window_display);
+
 	printf("\r");
 	fflush(stdout);
 
@@ -455,6 +453,12 @@ static	void	show_version (void)
 {
 	printf("ircII %s (Commit id: %lu) (Date of release: %s)\n\r", 
 			irc_version, commit_id, internal_version);
+	printf("Compile metadata: %s\n", compile_info);
+	printf("Compiler: %s\n", compiler_version);
+	printf("Configure options: %s\n", configure_args);
+	printf("Compilation FLAGS: %s\n", compile_cflags);
+	printf("Compilation LIBS: %s\n", compile_libs);
+	printf("Compilation link: %s\n", final_link);
 	exit (0);
 }
 
@@ -925,7 +929,7 @@ static	int		level = 0,
 	timer = TimerTimeout();
 
 	/* GO AHEAD AND WAIT FOR SOME DATA TO COME IN */
-	make_window_current(NULL);
+	make_window_current_by_refnum(0);
 	switch (do_wait(&timer))
 	{
 		/* Timeout -- Need to do timers */
@@ -1034,9 +1038,6 @@ int 	main (int argc, char *argv[])
 	SOCKSinit(argv[0]);
 #endif
         get_time(&start_time);
-#ifdef WITH_THREADED_STDOUT
-	tio_init();
-#endif
 
 	init_levels();
 	init_transforms();
@@ -1148,7 +1149,7 @@ int 	main (int argc, char *argv[])
 	if (dont_connect)
 		display_server_list();		/* Let user choose server */
 	else
-		current_window->server = 0;	/* Connect to default server */
+		set_window_server(0, 0);	/* Connect to default server */
 
 	/* The user may have used -S and /server in their startup script */
 	window_check_servers();
