@@ -193,7 +193,7 @@ static Binding *add_binding (const char *name, BindFunction func, char *alias)
 
 	bp = new_malloc(sizeof(Binding));
 	bp->name = malloc_strdup(name);
-	add_to_list((List **)&binding_list, (List *)bp);
+	ADD_TO_LIST_(&binding_list, bp);
 
 	bp->alias = NULL;
 	bp->func = NULL;
@@ -225,7 +225,7 @@ static void	remove_binding (char *name)
 	if (!name)
 		return;
 
-	if ((bp = (Binding *)remove_from_list((List **)&binding_list, name)))
+	if (REMOVE_FROM_LIST_(bp, &binding_list, name))
 	{
 		/* be sure to remove any keys bound to this binding first */
 		remove_bound_keys(head_keymap, bp);
@@ -275,10 +275,13 @@ static void	remove_bound_keys (Key *map, Binding *binding)
  */
 static Binding *	find_binding (const char *name) 
 {
+	Binding *retval;
+
 	if (!name)
 		return NULL;
 
-	return (Binding *)find_in_list((List **)&binding_list, name, 0);
+	FIND_IN_LIST_(retval, binding_list, name, 0);
+	return retval;
 }
 
 /*
@@ -687,7 +690,7 @@ static void *	timeout_keypress (void *lastp, Timeval pressed)
 		return NULL; 
 
 	/* 
-	 * If this node is not ambiguous (it is not bound here, but requires
+	 * If this node is not ambiguous (it is not bound here), but requires
 	 * more keys to complete, we have nothing to resolve.
 	 */
 	last = (Key *)lastp;
@@ -751,8 +754,8 @@ static int	do_input_timeouts (void *ignored)
 
 		/* Set up context and check the sequence */
 		last_input_screen = output_screen = screen;
-		make_window_current(screen->current_window);
-		from_server = current_window->server;
+		make_window_current_by_refnum(screen->input_window);
+		from_server = get_window_server(0);
 
 		screen->last_key = timeout_keypress(screen->last_key,
 						    screen->last_press);
