@@ -681,6 +681,10 @@ static	char	termcap[2048];		/* Bigger than we need, just in case */
 static	char	termcap2[2048];		/* Bigger than we need, just in case */
 static	char *	tptr = termcap2;
 
+static	void	term_establish_last_column (void);
+static void	term_enable_last_column (void);
+static void	term_disable_last_column (void);
+
 /*
  * term_echo: if 0, echo is turned off (all characters appear as blanks), if
  * non-zero, all is normal.  The function returns the old value of the
@@ -756,10 +760,7 @@ void	term_reset (void)
 	if (current_term->TI_rmcup)
 		tputs_x(current_term->TI_rmcup);
 #endif
-#if use_automargins
-	if (current_term->TI_am && current_term->TI_smam)
-		tputs_x(current_term->TI_smam);
-#endif
+	term_disable_last_column();
 	term_flush();
 }
 
@@ -776,10 +777,7 @@ SIGNAL_HANDLER(term_cont)
 		if (current_term->TI_smcup)
 			tputs_x(current_term->TI_smcup);
 #endif
-#if use_automargins
-		if (current_term->TI_rmam)
-			tputs_x(current_term->TI_rmam);
-#endif
+		term_establish_last_column();
 		need_redraw = 1;
 		tcsetattr(tty_des, TCSADRAIN, &newb);
 	}
@@ -1190,7 +1188,6 @@ int 	term_init (void)
 		tputs_x(current_term->TI_smcup);
 #endif
 
-#if use_automargins
 	/*
 	 * When you write a character to the last column of a line, most
 	 * terminal emulators will advance the cursor to the start of the
@@ -1205,9 +1202,7 @@ int 	term_init (void)
 	 * There are no guarantees it will work, since some emulators say they 
 	 * support turning off auto-margins, but they lie.
 	 */
-	if (current_term->TI_rmam)
-		tputs_x(current_term->TI_rmam);
-#endif
+	term_establish_last_column();
 
 	/*
 	 * Next we tell the kernel that it should support 8 bits both
@@ -1274,13 +1269,7 @@ int	term_resize (void)
 	}
 #	endif
 
-#if use_automargins
-	if (!current_term->TI_am || !current_term->TI_rmam)
-		current_term->TI_cols--;
-#else
-	current_term->TI_cols--;
-#endif
-
+	term_establish_last_column();
 	if ((old_li != current_term->TI_lines) || (old_co != current_term->TI_cols))
 	{
 		old_li = current_term->TI_lines;
@@ -1294,6 +1283,30 @@ int	term_resize (void)
 	return 0;
 }
 
+static	void	term_establish_last_column (void)
+{
+	if (get_int_var(AUTOMARGIN_OVERRIDE_VAR))
+		term_enable_last_column();
+	else if (current_term->TI_am && current_term->TI_rmam)
+		term_enable_last_column();
+	else
+	{
+		term_disable_last_column();
+		current_term->TI_cols--;
+	}
+}
+
+static void	term_enable_last_column (void)
+{
+	if (current_term->TI_am && current_term->TI_rmam)
+		tputs_x(current_term->TI_rmam);
+}
+
+static void	term_disable_last_column (void)
+{
+	if (current_term->TI_am && current_term->TI_smam)
+		tputs_x(current_term->TI_smam);
+}
 
 /* term_CE_clear_to_eol(): the clear to eol function, right? */
 void	term_clreol	(void)
@@ -1312,26 +1325,25 @@ void	term_beep (void)
 	}
 }
 
-/* XXX Deprecated */
-void	set_meta_8bit (void *stuff)
+void	set_automargin_override (void *stuff)
 {
-	VARIABLE *v;
-	int	value;
-
-	v = (VARIABLE *)stuff;
-	value = v->integer;
-
 	if (dumb_mode)
 		return;
 
-	if (value == 0)
-		current_term->TI_meta_mode = 0;
-	else if (value == 1)
-		current_term->TI_meta_mode = 1;
-	else if (value == 2)
-		current_term->TI_meta_mode = (current_term->TI_km == 0 ? 0 : 1);
+	/*
+	 * This is called whenever you /set automargin_override,
+	 * either way.  
+	 *
+	 * ON - The client should assume it can use the last column
+	 *	no matter what the circumstances appear to support
+	 * OFF - The client should use (or not use) the last column
+	 *	based on whether it appears to be safe to do so.
+	 */
+	term_establish_last_column();
+	need_redraw = 1;
 }
 
+
 /* Set the cursor position */
 void	term_gotoxy (int col, int row)
 {
@@ -1393,27 +1405,6 @@ void	term_clrscr (void)
 	}
 }
 
-#if 0
-/*
- * Move the cursor NUM spaces to the left, non-destruvtively if we can.
- */
-void	term_left (int num)
-{
-	if (num == 1 && current_term->TI_cub1)
-		tputs_x(current_term->TI_cub1);
-	else if (current_term->TI_cub)
-		tputs_x (tparm1(current_term->TI_cub, num));
-	else if (current_term->TI_mrcup)
-		tputs_x (tparm2(current_term->TI_mrcup, -num, 0));
-	else if (current_term->TI_cub1)
-		while (num--)
-			tputs_x(current_term->TI_cub1);
-	else if (current_term->TI_kbs)
-		while (num--)
-			tputs_x (current_term->TI_kbs);
-}
-#endif
-
 /*
  * Move the cursor NUM spaces to the right
  */
@@ -1430,57 +1421,6 @@ void	term_right (int num)
 			tputs_x(current_term->TI_cuf1);
 }
 
-#if 0
-/*
- * term_delete (int num)
- * Deletes NUM characters at the current position
- */
-void	term_delete (int num)
-{
-	if (current_term->TI_smdc)
-		tputs_x(current_term->TI_smdc);
-
-	if (current_term->TI_dch)
-		tputs_x (tparm1(current_term->TI_dch, num));
-	else if (current_term->TI_dch1)
-		while (num--)
-			tputs_x (current_term->TI_dch1);
-
-	if (current_term->TI_rmdc)
-		tputs_x (current_term->TI_rmdc);
-}
-
-/*
- * Insert character C at the curent cursor position.
- */
-void	term_insert (unsigned char c)
-{
-	if (current_term->TI_smir)
-		tputs_x (current_term->TI_smir);
-	else if (current_term->TI_ich1)
-		tputs_x (current_term->TI_ich1);
-	else if (current_term->TI_ich)
-		tputs_x (tparm1(current_term->TI_ich, 1));
-
-	term_inputline_putchar (c);
-
-	if (current_term->TI_rmir)
-		tputs_x(current_term->TI_rmir);
-}
-
-/*
- * Repeat the character C REP times in the most efficient way.
- */
-void	term_repeat (unsigned char c, int rep)
-{
-	if (current_term->TI_rep)
-		tputs_x(tparm2(current_term->TI_rep, (int)c, rep));
-	else
-		while (rep--)
-			putchar_x (c);
-}
-#endif
-
 /*
  * Scroll the screen N lines between lines TOP and BOT.
  */
@@ -1781,123 +1721,3 @@ static	char		retval[128];
 	return NULL;	
 }
 
-#ifdef WITH_THREADED_STDOUT
-
-#include <pthread.h>
-#include "tio.h"
-
-#define TIOBUFSZ	2048
-
-typedef struct tio_qentry_stru {
-	tio_file	*file;
-	int		 len, flush, close;
-struct	tio_qentry_stru	*next, *tail;
-	char 		 buf[TIOBUFSZ];
-} tio_qentry;
-
-struct tio_file_stru {
-	FILE		*stdio_file;
-	tio_qentry	*buf;
-};
-
-static void		tio_push(tio_file *);
-static tio_qentry	*new_tiobuf(tio_file *);
-
-tio_file	*tio_stdout;
-
-static	tio_qentry	tio_qhead;
-static	pthread_cond_t	tio_cond = PTHREAD_COND_INITIALIZER;
-static	pthread_mutex_t	tio_mtx = PTHREAD_MUTEX_INITIALIZER;
-static	pthread_t	tio_thread;
-
-static tio_qentry	*new_tiobuf(tio_file *f)
-{
-	tio_qentry	*ret;
-	ret = calloc(1, sizeof(*ret));
-	ret->file = f;
-	return ret;
-}
-
-void	tio_fputc(int c, tio_file *f)
-{
-	if (f->buf->len == TIOBUFSZ)
-		tio_push(f);
-	f->buf->buf[f->buf->len++] = c;
-}
-
-void	tio_fputs(const char *str, tio_file *stream)
-{
-	while (*str)
-		tio_fputc(*str++, stream);
-}
-
-tio_file	*tio_open(FILE *f)
-{
-	tio_file	*ret;
-
-	if (f == NULL)
-		return NULL;
-
-	ret = calloc(1, sizeof(*ret));
-	ret->stdio_file = f;
-	ret->buf = new_tiobuf(ret);
-	return ret;
-}
-
-void	tio_flush(tio_file *stream)
-{
-	stream->buf->flush = 1;
-	tio_push(stream);
-}
-
-static void	tio_push(tio_file *stream)
-{
-	pthread_mutex_lock(&tio_mtx);
-	if (!tio_qhead.next) {
-		tio_qhead.next = tio_qhead.tail = stream->buf;
-	} else {
-		tio_qhead.tail->next = stream->buf;
-		tio_qhead.tail = stream->buf;
-	}
-
-	pthread_cond_signal(&tio_cond);
-	pthread_mutex_unlock(&tio_mtx);
-
-	stream->buf = new_tiobuf(stream);
-}
-
-static void	*tio_thread_run(void *unused)
-{
-	for (;;) {
-		tio_qentry	*tq, *next;
-
-		pthread_mutex_lock(&tio_mtx);
-		if (tio_qhead.next == NULL)
-			pthread_cond_wait(&tio_cond, &tio_mtx);
-		tq = tio_qhead.next;
-		tio_qhead.next = tio_qhead.tail = NULL;
-		pthread_mutex_unlock(&tio_mtx);
-
-		for (next = tq ? tq->next : NULL; tq;
-		     tq = next, next = tq ? tq->next : NULL) {
-			if (tq->len)
-				fwrite(tq->buf, 1, tq->len, tq->file->stdio_file);
-			if (tq->flush)
-				fflush(tq->file->stdio_file);
-			free(tq);
-		}
-	}
-}
-
-void	tio_init(void)
-{
-	tio_stdout = tio_open(stdout);
-	pthread_create(&tio_thread, NULL, tio_thread_run, NULL);
-}
-
-void	tio_close (tio_file *stream)
-{
-	yell("Need to implement tio_close!");
-}
-
-#endif
