@@ -69,8 +69,8 @@ static	void	list_timers (const char *command);
  *		Delete timer with name <refnum>
  *	/TIMER -DELETE ALL
  *		Delete all timers
- *	/TIMER -DELETE_FOR_WINDOW <winref>
- *		Delete all WINDOW timers that are bound to <winref>.
+ *	/TIMER -DELETE_FOR_WINDOW <window>
+ *		Delete all WINDOW timers that are bound to <window>.
  *		<Winref> must be a number.  Use $winnum() to get that.
  *
  *  Updating Timers:
@@ -140,7 +140,7 @@ BUILT_IN_COMMAND(timercmd)
 	else
 	{
 		domain = WINDOW_TIMER;
-		domref = current_window ? (int)current_window->refnum : -1;
+		domref = get_window_refnum(0);
 	}
 
 	while (*args == '-' || *args == '/')
@@ -228,13 +228,13 @@ BUILT_IN_COMMAND(timercmd)
 	    else if (!my_strnicmp(flag + 1, "WINDOW", len))	/* WINDOW */
 	    {
 		char 	*na;
-		Window *win = NULL;
+		int	window = 0;
 
 		domain = WINDOW_TIMER;
 		if ((na = next_arg(args, &args)))
-			win = get_window_by_desc(na);
+			window = lookup_window(na);
 
-		if (!win)
+		if (window < 1)
 		{
 		    if (my_stricmp(na, "-1"))
 		    {
@@ -245,7 +245,7 @@ BUILT_IN_COMMAND(timercmd)
 			domref = -1;
 		}
 		else
-			domref = win->refnum;
+			domref = window;
 	    }
 	    else if (!my_strnicmp(flag + 1, "SERVER", len))	/* SERVER */
 	    {
@@ -1077,7 +1077,7 @@ void 	ExecuteTimers (void)
 	{
 		int	old_refnum;
 
-		old_refnum = current_window->refnum;
+		old_refnum = get_window_refnum(0);
 		current = PendingTimers;
 		unlink_timer(current);
 
@@ -1103,13 +1103,12 @@ void 	ExecuteTimers (void)
 		    else
 		    {
 			from_server = current->domref;
-			make_window_current_by_refnum(
-					get_winref_by_servref(from_server));
+			make_window_current_by_refnum(get_server_current_window(from_server));
 		    }
 		}
 		else if (current->domain == WINDOW_TIMER)
 		{
-		    if (!get_window_by_refnum(current->domref))
+		    if (get_window_refnum(current->domref) < 1)
 		    {
 			if (current->cancelable)
 			    goto advance;
@@ -1118,22 +1117,21 @@ void 	ExecuteTimers (void)
 		    else
 		    {
 			make_window_current_by_refnum(current->domref);
-			from_server = current_window->server;
+			from_server = get_window_server(0);
 		    }
 		}
 		else
 		{
 		    /* General timers focus on the current window. */
-		    if (current_window)
+		    if (get_window_refnum(0) > 0)
 		    {
-			if (current_window->server != from_server)
-			    from_server = current_window->server;
+			if (get_window_server(0) != from_server)
+			    from_server = get_window_server(0);
 		    }
 		    else
 		    {
 			if (from_server != NOSERV)
-			    make_window_current_by_refnum(
-				get_winref_by_servref(from_server));
+			    make_window_current_by_refnum(get_server_current_window(from_server));
 		    }
 		}
 
@@ -1302,7 +1300,7 @@ char *	timerctl (char *input)
  * The /WINDOW NUMBER command actually swaps the refnums of two windows:
  * It's possible that 'newref' isn't in use, so that's ok.
  */
-void    timers_swap_winrefs (unsigned oldref, unsigned newref)
+void    timers_swap_windows (unsigned oldref, unsigned newref)
 {
 	Timer *ref;
 
@@ -1320,7 +1318,7 @@ void    timers_swap_winrefs (unsigned oldref, unsigned newref)
         }
 }
 
-void    timers_merge_winrefs (unsigned oldref, unsigned newref)
+void    timers_merge_windows (unsigned oldref, unsigned newref)
 {
 	Timer *ref;
 
